
// In Overlays with ftw.theming
.overlay-open .select2-dropdown {
  z-index: $zindex-overlay + $zindex-dropdown;
}


// Display vertical list of selected items
.select2-container--default .select2-selection--multiple .select2-selection__choice {
  float: none;
  margin-right: 2em;
  margin-bottom: 0em;
}

li.select2-search, li.select2-results__option {
  margin-bottom: 0;
}

.newEntries {
  display: none;
}

.select2-results {
  .newTagHint {
    display: inline-block;
    margin-left: 0.5em;
    background-color: rgb(32, 191, 32);
    border-radius: 4px;
    padding: 0px 5px;
    font-size: 12px;
    position: relative;
    vertical-align: top;
    color: white;
  }
} 
